@@ -7,15 +7,15 @@ from maggma.builders import Builder
 from maggma.stores import Store
 from maggma.utils import grouper
 
-from pymatgen.core import Structure
 from emmet.builders.settings import EmmetBuildSettings
-from emmet.builders import SETTINGS
 from emmet.core.utils import group_structures, jsanitize
 from emmet.core.vasp.material import MaterialsDoc
 from emmet.core.vasp.task import TaskDocument
 
 __author__ = "Shyam Dwaraknath <shyamd@lbl.gov>"
 
+SETTINGS = EmmetBuildSettings()
+
 
 class MaterialsBuilder(Builder):
     """
